==> virtualbox_4.3.18-dfsg.orig.tar.xz: virtualbox-4.3.18-dfsg/src/VBox/Frontends/VirtualBox/nls/VirtualBox_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>UIGChooserItemGroup</name>
    <message numerus="yes">
        <location filename="../src/selector/graphics/chooser/UIGChooserItemGroup.cpp" line="663"/>
        <source>%n group(s)</source>
        <comment>Group item tool-tip / Group info</comment>
        <translation>
            <numerusform>%n group</numerusform>
            <numerusform>%n groups</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/selector/graphics/chooser/UIGChooserItemGroup.cpp" line="679"/>
        <source>%n machine(s)</source>
        <comment>Group item tool-tip / Machine info</comment>
        <translation>
            <numerusform>%n machine</numerusform>
            <numerusform>%n machines</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/selector/graphics/chooser/UIGChooserItemGroup.cpp" line="680"/>
        <source>(%n running)</source>
        <comment>Group item tool-tip / Running machine info</comment>
        <translation>
            <numerusform>(%n running)</numerusform>
            <numerusform>(%n running)</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UIMessageCenter</name>
    <message numerus="yes">
        <source>&lt;p&gt;The %n following virtual machine(s) are currently in a saved state: &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine(s) will be discarded. The other machine(s) will not be changed.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;The virtual machine &lt;b&gt;%1&lt;/b&gt; is currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine will be discarded. Note that the existing machine is not changed.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The virtual machines &lt;b&gt;%1&lt;/b&gt; are currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machines will be discarded. Note that the existing machines are not changed.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The %n following virtual machine(s) are currently in a saved state: &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine(s) will be discarded. The other machine(s) will not be changed.&lt;/p&gt;</source>
        <comment>This text is never used with n == 0.  Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many machines are in the list and doesn&apos;t need to be told).</comment>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;The virtual machine &lt;b&gt;%1&lt;/b&gt; is currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine will be discarded. Note that the existing machine is not changed.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The virtual machines &lt;b&gt;%1&lt;/b&gt; are currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machines will be discarded. Note that the existing machines are not changed.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/globals/UIMessageCenter.cpp" line="1576"/>
        <source>&lt;p&gt;The %n following virtual machine(s) are currently in a saved state: &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine(s) will be discarded. The other machine(s) will not be changed.&lt;/p&gt;</source>
        <comment>This text is never used with n == 0. Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many machines are in the list and doesn&apos;t need to be told).</comment>
        <translation>
            <numerusform>&lt;p&gt;The following virtual machine is currently in a saved state:  &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine will be discarded. Other machines will not changed.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The following virtual machines are currently in a saved state:  &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machines will be discarded. Other machines will not changed.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VBoxGlobal</name>
    <message numerus="yes">
        <location filename="../src/globals/VBoxGlobal.h" line="169"/>
        <source>%n year(s)</source>
        <translation>
            <numerusform>%n year</numerusform>
            <numerusform>%n years</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/globals/VBoxGlobal.h" line="174"/>
        <source>%n month(s)</source>
        <translation>
            <numerusform>%n month</numerusform>
            <numerusform>%n months</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/globals/VBoxGlobal.h" line="179"/>
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n day</numerusform>
            <numerusform>%n days</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/globals/VBoxGlobal.h" line="184"/>
        <source>%n hour(s)</source>
        <translation>
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/globals/VBoxGlobal.h" line="194"/>
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/globals/VBoxGlobal.h" line="189"/>
        <source>%n minute(s)</source>
        <translation>
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VBoxTakeSnapshotDlg</name>
    <message numerus="yes">
        <location filename="../src/VBoxTakeSnapshotDlg.cpp" line="73"/>
        <source>Warning: You are taking a snapshot of a running machine which has %n immutable image(s) attached to it. As long as you are working from this snapshot the immutable image(s) will not be reset to avoid loss of data.</source>
        <translation>
            <numerusform>Warning: You are taking a snapshot of a running machine which has %n immutable image attached to it. As long as you are working from this snapshot the immutable image will not be reset to avoid loss of data.</numerusform>
            <numerusform>Warning: You are taking a snapshot of a running machine which has %n immutable images attached to it. As long as you are working from this snapshot the immutable images will not be reset to avoid loss of data.</numerusform>
        </translation>
    </message>
</context>
</TS>

==> virtualbox_7.2.2-dfsg.orig.tar.xz: virtualbox-7.2.2/src/VBox/Frontends/VirtualBox/nls/VirtualBox_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>UIAddDiskEncryptionPasswordDialog</name>
    <message numerus="yes">
        <source>This virtual machine is password protected. Please enter the %n encryption password(s) below.</source>
        <comment>This text is never used with n == 0. Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many passwords are in the list and doesn&apos;t need to be told).</comment>
        <translation>
            <numerusform>This virtual machine is password protected. Please enter the encryption password below.</numerusform>
            <numerusform>This virtual machine is password protected. Please enter the encryption passwords below.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;nobr&gt;Used by the following %n hard disk(s):&lt;/nobr&gt;&lt;br&gt;%1</source>
        <comment>This text is never used with n == 0. Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many hard drives are in the tool-tip and doesn&apos;t need to be told).</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UIChooserItemGroup</name>
    <message numerus="yes">
        <source>%n group(s)</source>
        <comment>Group item tool-tip / Group info</comment>
        <translation type="unfinished">
            <numerusform>%n group</numerusform>
            <numerusform>%n groups</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n machine(s)</source>
        <comment>Group item tool-tip / Machine info</comment>
        <translation type="unfinished">
            <numerusform>%n machine</numerusform>
            <numerusform>%n machines</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n running)</source>
        <comment>Group item tool-tip / Running machine info</comment>
        <translation type="unfinished">
            <numerusform>(%n running)</numerusform>
            <numerusform>(%n running)</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UICommon</name>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="vanished">
            <numerusform>%n year</numerusform>
            <numerusform>%n years</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation type="vanished">
            <numerusform>%n month</numerusform>
            <numerusform>%n months</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="vanished">
            <numerusform>%n day</numerusform>
            <numerusform>%n days</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="vanished">
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="vanished">
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="vanished">
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UIEncryptionDataModel</name>
    <message numerus="yes">
        <source>Used by the following %n hard drive(s):&lt;br&gt;%1</source>
        <comment>This text is never used with n == 0. Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many hard drives are in the tool-tip and doesn&apos;t need to be told).</comment>
        <translation type="obsolete">
            <numerusform>Used by the following hard drive:&lt;br&gt;%1</numerusform>
            <numerusform>Used by the following hard drives:&lt;br&gt;%1</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UIGChooserItemGroup</name>
    <message numerus="yes">
        <source>%n group(s)</source>
        <comment>Group item tool-tip / Group info</comment>
        <translation type="vanished">
            <numerusform>%n group</numerusform>
            <numerusform>%n groups</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n machine(s)</source>
        <comment>Group item tool-tip / Machine info</comment>
        <translation type="vanished">
            <numerusform>%n machine</numerusform>
            <numerusform>%n machines</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n running)</source>
        <comment>Group item tool-tip / Running machine info</comment>
        <translation type="vanished">
            <numerusform>(%n running)</numerusform>
            <numerusform>(%n running)</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UIMessageCenter</name>
    <message numerus="yes">
        <source>&lt;p&gt;The %n following virtual machine(s) are currently in a saved state: &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine(s) will be discarded. The other machine(s) will not be changed.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;The virtual machine &lt;b&gt;%1&lt;/b&gt; is currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine will be discarded. Note that the existing machine is not changed.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The virtual machines &lt;b&gt;%1&lt;/b&gt; are currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machines will be discarded. Note that the existing machines are not changed.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The %n following virtual machine(s) are currently in a saved state: &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine(s) will be discarded. The other machine(s) will not be changed.&lt;/p&gt;</source>
        <comment>This text is never used with n == 0.  Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many machines are in the list and doesn&apos;t need to be told).</comment>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;The virtual machine &lt;b&gt;%1&lt;/b&gt; is currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine will be discarded. Note that the existing machine is not changed.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The virtual machines &lt;b&gt;%1&lt;/b&gt; are currently in a saved state.&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machines will be discarded. Note that the existing machines are not changed.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The %n following virtual machine(s) are currently in a saved state: &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine(s) will be discarded. The other machine(s) will not be changed.&lt;/p&gt;</source>
        <comment>This text is never used with n == 0. Feel free to drop the %n where possible, we only included it because of problems with Qt Linguist (but the user can see how many machines are in the list and doesn&apos;t need to be told).</comment>
        <translation>
            <numerusform>&lt;p&gt;The following virtual machine is currently in a saved state:  &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machine will be discarded. Other machines will not changed.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;The following virtual machines are currently in a saved state:  &lt;b&gt;%1&lt;/b&gt;&lt;/p&gt;&lt;p&gt;If you continue the runtime state of the exported machines will be discarded. Other machines will not changed.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UITakeSnapshotDialog</name>
    <message numerus="yes">
        <source>Warning: You are taking a snapshot of a running machine which has %n immutable image(s) attached to it. As long as you are working from this snapshot the immutable image(s) will not be reset to avoid loss of data.</source>
        <translation type="unfinished">
            <numerusform>Warning: You are taking a snapshot of a running machine which has %n immutable image attached to it. As long as you are working from this snapshot the immutable image will not be reset to avoid loss of data.</numerusform>
            <numerusform>Warning: You are taking a snapshot of a running machine which has %n immutable images attached to it. As long as you are working from this snapshot the immutable images will not be reset to avoid loss of data.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UITranslator</name>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year</numerusform>
            <numerusform>%n years</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation type="unfinished">
            <numerusform>%n month</numerusform>
            <numerusform>%n months</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day</numerusform>
            <numerusform>%n days</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour</numerusform>
            <numerusform>%n hours</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute</numerusform>
            <numerusform>%n minutes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second</numerusform>
            <numerusform>%n seconds</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished">
            <numerusform>%n year ago</numerusform>
            <numerusform>%n years ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished">
            <numerusform>%n month ago</numerusform>
            <numerusform>%n months ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform>%n day ago</numerusform>
            <numerusform>%n days ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform>%n hour ago</numerusform>
            <numerusform>%n hours ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform>%n minute ago</numerusform>
            <numerusform>%n minutes ago</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform>%n second ago</numerusform>
            <numerusform>%n seconds ago</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VBoxTakeSnapshotDlg</name>
    <message numerus="yes">
        <source>Warning: You are taking a snapshot of a running machine which has %n immutable image(s) attached to it. As long as you are working from this snapshot the immutable image(s) will not be reset to avoid loss of data.</source>
        <translation type="vanished">
            <numerusform>Warning: You are taking a snapshot of a running machine which has %n immutable image attached to it. As long as you are working from this snapshot the immutable image will not be reset to avoid loss of data.</numerusform>
            <numerusform>Warning: You are taking a snapshot of a running machine which has %n immutable images attached to it. As long as you are working from this snapshot the immutable images will not be reset to avoid loss of data.</numerusform>
        </translation>
    </message>
</context>
</TS>
